@@ -7,8 +7,6 @@ import shutil
 import socket
 import sys
 import tempfile
-import urllib
-import urllib2
 from cgi import parse_header
 from httplib import BadStatusLine
 
@@ -195,8 +193,7 @@ class PluginDownload(object):
                     log.info('Downloading: %s' % entry['title'])
                 self.download_entry(task, entry, url, tmp_path)
         except RequestException as e:
-            # TODO: Improve this error message?
-            log.warning('RequestException %s' % e)
+            log.warning('RequestException %s, while downloading %s' % (e, url))
             return 'Network error during request: %s' % e
         except BadStatusLine as e:
             log.warning('Failed to reach server. Reason: %s' % getattr(e, 'message', 'N/A'))
